##
##  cdb.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_cdb       0.75
%define       V_tinycdb   0.81
%define       V_cdb_file  1.05

#   package information
Name:         cdb
Summary:      Constant Database
URL:          http://cr.yp.to/cdb.html
Vendor:       D. J. Bernstein
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      Public Domain
Version:      %{V_cdb}
Release:      20231226

#   package options
%option       with_perl   no

#   list of sources
Source0:      http://cr.yp.to/cdb/cdb-%{version}.tar.gz
Source1:      http://www.corpit.ru/mjt/tinycdb/tinycdb-%{V_tinycdb}.tar.gz
Source2:      http://www.cpan.org/modules/by-module/CDB_File/CDB_File-%{V_cdb_file}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    CDB is a fast, reliable, simple package for creating and reading
    constant databases. Its database structure provides fast
    lookups, low overhead, no random limits, fast atomic database
    replacement, and fast database dumps: CDB is designed to be used
    in mission-critical applications like e-mail. Database replacement
    is safe against system crashes. Readers don't have to pause during
    a rewrite. This package contains both the original CDB, the
    improved TinyCDB and optionally the CDB_File Perl API.

%track
    prog cdb = {
        version   = %{V_cdb}
        url       = http://cr.yp.to/cdb/install.html
        regex     = cdb-(__VER__)\.tar\.gz
    }
    prog cdb:tinycdb = {
        version   = %{V_tinycdb}
        url       = http://www.corpit.ru/mjt/tinycdb.html
        regex     = tinycdb-(__VER__)\.tar\.gz
    }
    prog cdb:CDB_File = {
        version   = %{V_cdb_file}
        url       = http://www.cpan.org/modules/by-module/CDB_File/
        regex     = CDB_File-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2

%build
    ( cd cdb-%{V_cdb}
      echo "$RPM_BUILD_ROOT%{l_prefix}" >conf-home
      echo "%{l_cc} %{l_cflags -O}" >conf-cc
      echo "%{l_cc} %{l_ldflags}" >conf-ld
      %{l_make} %{l_mflags} it
    ) || exit $?
    ( cd tinycdb-%{V_tinycdb}
      %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O}"
    ) || exit $?
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d CDB_File-%{V_cdb_file} configure build
%endif

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/include \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man3 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5
    ( cd cdb-%{V_cdb}
      %{l_shtool} install -c -s -m 755 \
          cdbdump cdbget cdbmake cdbstats \
          $RPM_BUILD_ROOT%{l_prefix}/bin/
      %{l_shtool} install -c -m 644 \
          cdb.h $RPM_BUILD_ROOT%{l_prefix}/include/
      %{l_shtool} install -c -m 644 \
          cdb.a $RPM_BUILD_ROOT%{l_prefix}/lib/libcdb.a
    ) || exit $?
    ( cd tinycdb-%{V_tinycdb}
      %{l_shtool} install -c -s -m 755 \
          cdb $RPM_BUILD_ROOT%{l_prefix}/bin/tinycdb
      %{l_shtool} install -c -m 644 \
          cdb.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/tinycdb.1
      %{l_shtool} install -c -m 644 \
          cdb.3 $RPM_BUILD_ROOT%{l_prefix}/man/man3/tinycdb.3
      %{l_shtool} install -c -m 644 \
          cdb.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/
      %{l_shtool} install -c -m 644 \
          cdb.h $RPM_BUILD_ROOT%{l_prefix}/include/tinycdb.h
      %{l_shtool} install -c -m 644 \
          libcdb.a $RPM_BUILD_ROOT%{l_prefix}/lib/libtinycdb.a
    ) || exit $?
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d CDB_File-%{V_cdb_file} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

